@@ -453,7 +453,7 @@ class rdesktop:
                         tempexp = tempexp | 0x80
                 if self.chk_exp_composition.get_active() == False :
                         tempexp = tempexp | 0x20
-                if self.chk_exp_drag.get_active() == False :
+                if self.chk_exp_drag.get_active() == True :
                         tempexp = tempexp | 0x02
                 if self.chk_exp_animation.get_active() == False :
                         tempexp = tempexp | 0x04
